import { Component, ViewChild } from "@angular/core";
import { FormBuilder, FormGroup, NgForm, Validators } from "@angular/forms";
import { LoginService } from "../../service/login.service";
import { ToastrService } from "ngx-toastr";
@Component({
  selector: "app-profil-information",
  templateUrl: "./profil-information.component.html",
  styleUrls: ["./profil-information.component.css"],
})
export class ProfilInformationComponent {
  @ViewChild("f", { read: true }) userProfileForm: NgForm;
  public breadcrumb: any;
  profilInfo: FormGroup;
  activeTab: string = "profile-info2";
  submitted = false;
  storedData: any;
  disableButton: boolean = false

  url: any = '';
  fileSelected: any = null;

  constructor(
    private formBuilder: FormBuilder,
    private authService: LoginService,
    private toastr: ToastrService,
  ) {}

  ngOnInit(): void {
    this.storedData = JSON.parse(localStorage.getItem("account_info"));
    this.profilInfo = this.formBuilder.group({
      firstName: ["", Validators.required],
      lastName: ["", Validators.required],
      email: ["", Validators.required],
      phone: ["", Validators.required],
      image: [null]
    });
    this.dataProfil(this.storedData.sub)
  }

  dataProfil(userId){
    this.authService.getDataProfil(userId).subscribe(data => {
      this.profilInfo.patchValue({
        firstName: data.data.firstname,
        lastName: data.data.lastname,
        email: data.data.email,
        phone: data.data.phone,
        image: [null]
      });
      this.url = data.data.image_path
    });
    
  }

  onSelectFile(event) {
    if (event.target.files && event.target.files[0]) {
      const file = event.target.files[0];
      this.fileSelected = file;
      if (!file.type.startsWith('image')) {
        this.toastr.error("Warning", "Please select an image file.", {
          timeOut: 5000,
          closeButton: true,
        });
        this.profilInfo.patchValue({
          image: null
        });
        return;
      }

      const reader = new FileReader();
      reader.readAsDataURL(file);

      reader.onload = (e) => {
        this.url = e.target.result;
      };
    }
  }

  public deleteImage() {
    this.url = null;
    if (this.url === null) {
      this.disableButton = true
    } else{
      this.disableButton = false
    }
    this.profilInfo.patchValue({ image: null });
  }

  selectTab(tabName: string) {
    this.activeTab = tabName;
  }

  get f() {
    return this.profilInfo.controls;
  }

  onProjectInfoSubmit() {
    this.submitted = true;
    if (this.profilInfo.invalid) {
      return;
    }

    const formData = new FormData();
    formData.append("firstname", this.profilInfo.get("firstName").value);
    formData.append("lastname", this.profilInfo.get("lastName").value);
    formData.append("email", this.profilInfo.get("email").value);
    formData.append("phone", this.profilInfo.get("phone").value);
    formData.append("statusId", "2");
    formData.append("buildingId", "4");
    formData.append("image", this.fileSelected);
    
    this.authService.updateProfile(formData, this.storedData.sub).subscribe(
      (response) => {
        console.log("Profile updated successfully:", response);
        this.toastr.success("success", "Profile updated successfully.", {
          timeOut: 5000,
          closeButton: true,
        });
        // Handle success response
      },
      (error) => {
        console.error("Profile update failed:", error);
        this.toastr.error("Error", "Profile update failed.", {
          timeOut: 5000,
          closeButton: true,
        });
        // Handle error response
      }
    );
  }

  cancel() {
    this.dataProfil(this.storedData.sub);
    this.disableButton = false
  }
}
